super_tree library
Classes
- ContextMenuItem
- A single item representing an action in the ContextMenuOverlay.
- ContextMenuOverlay
- A utility to display a platform-agnostic, customizable context menu using Flutter's Overlay system.
- CupertinoFileSystemIconProvider
- A default Cupertino icon provider for file systems.
- FileItem
- A prebuilt data item representing a file. Files cannot have children and cannot receive items dropped inside them.
- FileSystemIconProvider
- Defines an interface for providing icons to a FileSystemSuperTree. By passing the whole TreeNode, consumers have access to the data, as well as the node's expansion state, selected state, and depth.
- FileSystemItem
- A base ergonomic class for representing file system structures in a tree view.
- FileSystemSuperTree
- A convenience widget that wraps SuperTreeView specifically configured for FileSystemItems.
- FileSystemTreeTheme
- Theme tokens for reusable file-system tree presentation.
- FolderItem
- A prebuilt data item representing a folder. Folders can have children and can receive drops.
-
FuzzyTreeFilter<
T> - Reusable matcher builder that combines keyword rules, custom matchers, and the default ordered-character fuzzy matcher.
- MaterialFileSystemIconProvider
- A default material icon provider for file systems.
-
SuperTreeIconProvider<
T> -
A base interface for providing icons to a SuperTree instance based on its Data Class
T. - SuperTreeNodeContract
- Optional shared contract for tree node payload models.
-
SuperTreeNodeWidget<
T> - Renders a single node row in the SuperTreeView.
- SuperTreeThemePreset
- A reusable bundle of style and icon defaults for a SuperTree experience.
- SuperTreeThemes
- Prebuilt visual presets for common SuperTree use cases.
-
SuperTreeView<
T> - The entry point for rendering the tree view.
- TodoItem
- A prebuilt data item representing a generic todo task.
- TodoListSuperTree
- A convenience widget that wraps SuperTreeView specifically configured for TodoItems. It provides a checkbox out-of-the-box and sorts uncompleted items first by default.
-
TreeController<
T> - Manages the state and structure of the tree.
-
TreeDragAndDropConfig<
T> - Configuration for drag-and-drop behavior in SuperTreeView.
- TreeDragAndDropStyle
- Visual style options specific to drag-and-drop interactions in SuperTreeView.
-
TreeDragPayload<
T> - Payload carried during drag-and-drop operations.
-
TreeEvent<
T> - Base sealed class for all events emitted by TreeController.
-
TreeFilterKeywordRule<
T> - Maps specific query keywords to a node predicate result.
- TreeFuzzyMatchResult
- Match metadata used to drive fuzzy-search highlighting.
- TreeHighlightedLabel
- Renders text with fuzzy-match highlights using RichText.
- TreeIntegrityIssue
- Describes a non-fatal graph integrity issue.
-
TreeNode<
T> - Represents a single node in the SuperTreeView.
-
TreeNodeAddedEvent<
T> - Emitted when one or more nodes are added to the tree via TreeController.addRoot or TreeController.addChild.
- TreeNodeAsyncState
- Read-only async UI state for a node.
-
TreeNodeMovedEvent<
T> - Emitted when one or more nodes are moved within the tree via TreeController.moveNode or TreeController.moveNodes.
-
TreeNodeRemovedEvent<
T> - Emitted when a node is removed from the tree via TreeController.removeNode.
-
TreeNodeRenamedEvent<
T> - Emitted when a node is renamed via TreeController.renameNode.
-
TreeSearchController<
T> - Coordinates query filtering and expansion behavior for a TreeController.
- TreeSort
- Pre-made sorting comparators for the Super Tree.
-
TreeViewConfig<
T> - Configuration for the interaction behaviors of the SuperTreeView.
- TreeViewStyle
- Configuration for the visual appearance of the SuperTreeView.
Enums
- ExpansionTrigger
- Behaviors that trigger a node's expansion.
- NodeDropPosition
- The target drop position relative to a node's bounds.
- SelectionMode
- Selection modes for the tree nodes.
- TreeIntegrityIssueType
- Integrity issue types emitted when operations are rejected to keep the graph valid.
- TreeNamingStrategy
- Strategies for triggering in-tree node renaming.
- TreeNodeState
- Lazy-loading lifecycle state for a tree node.
- TreeSearchExpansionBehavior
- Expansion behavior to use while a search query is active.
Mixins
- SuperTreeData
- An optional mixin that gives data items intelligent defaulting for the tree view.
Functions
-
defaultTreeFuzzyMatcher(
String query, String candidate) → TreeFuzzyMatchResult? - Default ordered-character fuzzy matcher.
-
prefixBuilderFromIconProvider<
T> ({required SuperTreeIconProvider< T> iconProvider, double leadingSpacing = 4.0}) → Widget Function(BuildContext, TreeNode<T> ) -
Builds a standardized
prefixBuilderfor SuperTreeView from an icon provider.
Typedefs
-
SuperTreeController<
T> = TreeController< T> - Preferred user-facing alias for TreeController.
-
SuperTreeEvent<
T> = TreeEvent< T> - Preferred user-facing alias for TreeEvent.
-
SuperTreeEventSubscription<
T> = StreamSubscription< SuperTreeEvent< T> > - Preferred user-facing alias for StreamSubscription.
- SuperTreeExpansionTrigger = ExpansionTrigger
- Preferred user-facing alias for ExpansionTrigger.
- SuperTreeIntegrityIssue = TreeIntegrityIssue
- Preferred user-facing alias for TreeIntegrityIssue.
- SuperTreeIntegrityIssueType = TreeIntegrityIssueType
- Preferred user-facing alias for TreeIntegrityIssueType.
-
SuperTreeLoadChildrenCallback<
T> = TreeLoadChildrenCallback< T> - Preferred user-facing alias for TreeLoadChildrenCallback.
- SuperTreeNamingStrategy = TreeNamingStrategy
- Preferred user-facing alias for TreeNamingStrategy.
-
SuperTreeNode<
T> = TreeNode< T> - Preferred user-facing alias for TreeNode.
-
SuperTreeNodeAddedEvent<
T> = TreeNodeAddedEvent< T> - Preferred user-facing alias for TreeNodeAddedEvent.
- SuperTreeNodeAsyncState = TreeNodeAsyncState
- Preferred user-facing alias for TreeNodeAsyncState.
-
SuperTreeNodeMovedEvent<
T> = TreeNodeMovedEvent< T> - Preferred user-facing alias for TreeNodeMovedEvent.
-
SuperTreeNodeRemovedEvent<
T> = TreeNodeRemovedEvent< T> - Preferred user-facing alias for TreeNodeRemovedEvent.
-
SuperTreeNodeRenamedEvent<
T> = TreeNodeRenamedEvent< T> - Preferred user-facing alias for TreeNodeRenamedEvent.
-
SuperTreeSearchController<
T> = TreeSearchController< T> - Preferred user-facing alias for TreeSearchController.
- SuperTreeSelectionMode = SelectionMode
- Preferred user-facing alias for SelectionMode.
-
SuperTreeViewConfig<
T> = TreeViewConfig< T> - Preferred user-facing alias for TreeViewConfig.
- SuperTreeViewStyle = TreeViewStyle
- Preferred user-facing alias for TreeViewStyle.
-
TreeFilterCustomMatcher<
T> = TreeFuzzyMatchResult? Function(String normalizedQuery, TreeNode< T> node, String candidate) - Extra query matcher hook used by FuzzyTreeFilter before the default matcher.
- TreeFuzzyMatcher = TreeFuzzyMatchResult? Function(String query, String candidate)
- Signature for custom fuzzy match algorithms.
-
TreeLabelProvider<
T> = String Function(T data) -
Signature for providing a string label from a data object of type
T. -
TreeLoadChildrenCallback<
T> = Future< List< Function(TreeNode<TreeNode< >T> >T> node) - Callback used to lazily resolve children for a node.
-
TreeNodeFilter<
T> = bool Function(TreeNode< T> node) - Predicate used to include/exclude nodes during filtering.
-
TreeNodeQueryMatcher<
T> = TreeFuzzyMatchResult? Function(String query, TreeNode< T> node, String candidate) - Query matcher that can use node metadata and label text.
-
TreeSearchExpansionStrategy<
T> = void Function(TreeController< T> controller, Set<String> matchedNodeIds) - Optional callback to provide custom expansion behavior during search.
-
TreeSearchLabelProvider<
T> = String Function(T data) - Label extractor used by query-based filtering.
-
TreeSearchMatcher<
T> = TreeFuzzyMatchResult? Function(String query, TreeNode< T> node, String candidate) - Optional callback to provide custom search matching behavior.