TreeSearchController<T> class
Coordinates query filtering and expansion behavior for a TreeController.
- Inheritance
-
- Object
- ChangeNotifier
- TreeSearchController
Constructors
-
TreeSearchController({required TreeController<
T> treeController, required TreeSearchLabelProvider<T> labelProvider, TreeNodeFilter<T> ? baseFilter, TreeSearchMatcher<T> ? searchMatcher, TreeFuzzyMatcher fuzzyMatcher = defaultTreeFuzzyMatcher, TreeSearchExpansionBehavior expansionBehavior = TreeSearchExpansionBehavior.expandAncestors, TreeSearchExpansionStrategy<T> ? expansionStrategy, bool restoreExpansionOnClear = true})
Properties
-
baseFilter
→ TreeNodeFilter<
T> ? -
final
- expansionBehavior → TreeSearchExpansionBehavior
-
final
-
expansionStrategy
→ TreeSearchExpansionStrategy<
T> ? -
final
- fuzzyMatcher → TreeFuzzyMatcher
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- hasQuery → bool
-
no setter
-
labelProvider
→ TreeSearchLabelProvider<
T> -
final
- query → String
-
no setter
- restoreExpansionOnClear → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
searchMatcher
→ TreeSearchMatcher<
T> ? -
final
-
treeController
→ TreeController<
T> -
final
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
clearSearch(
) → void - Clears search and optionally restores expansion state.
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
search(
String nextQuery) → void - Applies query search and updates the associated treeController.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited